@@ -1,4 +1,7 @@
-version = '0.3.5'
+version = '0.4.0'
+
+from os import path
+cwd = path.abspath(path.dirname(__file__))
 
 import nib.yaml as yaml
 from nib.config import Config
