@@ -1,19 +1,34 @@
 import jinja2
 from jinja2 import Environment, FileSystemLoader, Template
 from os import path
+import time
+
+jinja_filters = {}
+
+def jinja(name):
+    def decorator(f):
+        jinja_filters[name] = f
+        return f
+    return decorator
 
 class Render(object):
     def __init__(self, options, documents):
         self.options = options
         self.documents = documents
+
         self.loader = FileSystemLoader(path.abspath(options['template_path']))
         self.env = Environment(loader=self.loader)
+        for name in jinja_filters:
+            self.env.filters[name] = jinja_filters[name]
+
+        self.site = dict(options['site'], documents=documents)
+        self.now = time.time()
 
         for document in documents:
             params = {
-                'site': self.options['site'],
-                'documents': self.documents,
-                'document': document,
+                'now': self.now,
+                'site': self.site,
+                'page': document,
             }
             params.update(document)
 
@@ -21,15 +36,19 @@ class Render(object):
             document.content = Template(document.content).render(**params)
 
     def render(self, document):
-        template = self.env.get_template(document['template'])
+        if 'template' in document:
+            template = self.env.get_template(document['template'])
 
-        params = {
-            'site': self.options['site'],
-            'documents': self.documents,
-            'document': document,
-            'content': document.content,
-            'short': document.short,
-        }
-        params.update(document)
+            params = {
+                'now': self.now,
+                'site': self.options['site'],
+                'page': document,
+                'content': document.content,
+                'short': document.short,
+            }
+            params.update(document)
 
-        return template.render(**params)
+            return template.render(**params)
+
+        else:
+            return document.content
